Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(634)

Unified Diff: net/base/origin_bound_cert_service.h

Issue 9617039: Change Origin bound certs -> Domain bound certs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: explanitory comment Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/base/origin_bound_cert_service.h
diff --git a/net/base/origin_bound_cert_service.h b/net/base/origin_bound_cert_service.h
index d9096df772c0a5b0b640fd7620c346e22c2f182c..8157b79ab7e921d6da51822d4b85c1a7cb5c0ad6 100644
--- a/net/base/origin_bound_cert_service.h
+++ b/net/base/origin_bound_cert_service.h
@@ -24,9 +24,11 @@ class OriginBoundCertServiceJob;
class OriginBoundCertServiceWorker;
class OriginBoundCertStore;
// A class for creating and fetching origin bound certs.
// Inherits from NonThreadSafe in order to use the function
// |CalledOnValidThread|.
+// Note: For historical reasons, this class is called OriginBoundCertService,
+// but it's really a DomainBoundCertService.
class NET_EXPORT OriginBoundCertService
: NON_EXPORTED_BASE(public base::NonThreadSafe) {
public:
@@ -49,7 +51,7 @@ class NET_EXPORT OriginBoundCertService
// the origin otherwise.
static std::string GetDomainForHost(const std::string& host);
// Fetches the origin bound cert for the specified origin of the specified
// type if one exists and creates one otherwise. Returns OK if successful or
// an error code upon failure.
//
@@ -101,7 +103,7 @@ class NET_EXPORT OriginBoundCertService
// |serial_number| is passed in because it is created with the function
// base::RandInt, which opens the file /dev/urandom. /dev/urandom is opened
// with a LazyInstance, which is not allowed on a worker thread.
- static int GenerateCert(const std::string& origin,
+ static int GenerateCert(const std::string& domain,
Ryan Hamilton 2012/03/07 04:46:06 Does this include the host and port for the domain
mattm 2012/03/15 01:48:44 just the host.
SSLClientCertType type,
uint32 serial_number,
base::Time* creation_time,
@@ -109,7 +111,7 @@ class NET_EXPORT OriginBoundCertService
std::string* private_key,
std::string* cert);
- void HandleResult(const std::string& origin,
+ void HandleResult(const std::string& domain,
int error,
SSLClientCertType type,
base::Time creation_time,
@@ -119,7 +121,7 @@ class NET_EXPORT OriginBoundCertService
scoped_ptr<OriginBoundCertStore> origin_bound_cert_store_;
// inflight_ maps from an origin to an active generation which is taking
// place.
std::map<std::string, OriginBoundCertServiceJob*> inflight_;
@@ -24,9 +24,11 @@ class OriginBoundCertServiceJob;
class OriginBoundCertServiceWorker;
class OriginBoundCertStore;
-// A class for creating and fetching origin bound certs.
+// A class for creating and fetching domain bound certs.
// Inherits from NonThreadSafe in order to use the function
// |CalledOnValidThread|.
@@ -49,7 +51,7 @@ class NET_EXPORT OriginBoundCertService
// the origin otherwise.
static std::string GetDomainForHost(const std::string& host);
- // Fetches the origin bound cert for the specified origin of the specified
+ // Fetches the domain bound cert for the specified origin of the specified
// type if one exists and creates one otherwise. Returns OK if successful or
// an error code upon failure.
@@ -119,7 +121,7 @@ class NET_EXPORT OriginBoundCertService
scoped_ptr<OriginBoundCertStore> origin_bound_cert_store_;
- // inflight_ maps from an origin to an active generation which is taking
+ // inflight_ maps from a domain to an active generation which is taking
// place.
std::map<std::string, OriginBoundCertServiceJob*> inflight_;

Powered by Google App Engine
This is Rietveld 408576698